@@ -159,18 +159,23 @@ class Document:
             "GET",
         )
 
+    async def _set_asset(self, path, file_name, mime_type, contents):
+        return await self.accqsure._query(
+            f"/document/{self.id}/asset/{path}",
+            "PUT",
+            params={"file_name": file_name},
+            data=contents,
+            headers={"Content-Type": mime_type},
+        )
+
     async def _set_content_item(self, name, file_name, mime_type, contents):
         if not self._content_id:
             raise SpecificationError(
                 "content_id", "Content not finalized for inspection"
             )
 
-        return await self.accqsure._query(
-            f"/inspection/{self.id}/asset/{self._content_id}/{name}",
-            "PUT",
-            params={"file_name": file_name},
-            data=contents,
-            headers={"Content-Type": mime_type},
+        return await self._set_asset(
+            f"{self._content_id}/{name}", file_name, mime_type, contents
         )
 
     async def list_manifests(self):
